# Vulnerability Search

<picture>
  <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/s3r3t0/sereto/main/docs/assets/logo/sereto_block_white.svg">
  <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/s3r3t0/sereto/main/docs/assets/logo/sereto_block_black.svg">
  <img src="https://raw.githubusercontent.com/s3r3t0/sereto/main/docs/assets/logo/sereto_block_black.svg" alt="SeReTo logo" align="right" height="150"/>
</picture>

[![GitHub release](https://img.shields.io/github/v/release/s3r3t0/vulnerability-search)][release]
[![GitHub release date](https://img.shields.io/github/release-date/s3r3t0/vulnerability-search)][release]
[![GitHub last commit](https://img.shields.io/github/last-commit/s3r3t0/vulnerability-search)](https://github.com/s3r3t0/vulnerability-search/commit/main)

[![GitHub License](https://img.shields.io/github/license/s3r3t0/vulnerability-search)][license]
![GitHub language count](https://img.shields.io/github/languages/count/s3r3t0/vulnerability-search)
![GitHub top language](https://img.shields.io/github/languages/top/s3r3t0/vulnerability-search)

A command-line utility to search vulnerabilities in National Vulnerability Database (NVD) and Open Source Vulnerabilities (OSV).

The primary focus of the tool is to help with reporting vulnerable software using [Security Reporting Tool (SeReTo)][SeReTo].

## Table of Contents

- [Vulnerability Search](#vulnerability-search)
  - [Table of Contents](#table-of-contents)
  - [Getting Started](#getting-started)
  - [Versioning](#versioning)
  - [License](#license)
  - [Acknowledgements](#acknowledgements)

## Getting Started

## Versioning

We use [Semantic Versioning][semver] for versioning. For the versions available, see the [tags on this repository][tags] or the full [Changelog].

## License

This project is licensed under the [GNU General Public License version 3][license] - see the [LICENSE][license] file for details.

## Acknowledgements

> Created with support of [NN Management Services, s.r.o.][nn]

[SeReTo]: https://github.com/s3r3t0/sereto
[semver]: https://semver.org
[tags]: https://github.com/s3r3t0/vulnerability-search/tags
[license]: https://github.com/s3r3t0/vulnerability-search/blob/main/LICENSE
[Changelog]: https://github.com/s3r3t0/vulnerability-search/blob/main/CHANGELOG.md
[nn]: https://www.nn.cz/kariera/en/nn-digital-hub/
[release]: https://github.com/s3r3t0/vulnerability-search/releases/latest
